##  Create A Dedicated User Account for Integration
You need an admin role in SAP LeanIX for setting up the configuration, as well as in Collibra. On the Collibra side, as a best practice, ensure the integration is linked to a dedicated user account specifically created for this purpose with greater permissions than a regular user account. This also ensures proper access management and continuity. For a detailed guide on configuration, see [Configuring Collibra Integration](https://help.sap.com/docs/leanix/ea/configuring-collibra-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Setting up the integration between SAP LeanIX and Collibra involves configuring authentication \(Basic Auth or OAuth 2.0\) and ensuring credentials validity for secure access.").
